==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/RadialAreaSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeriesDescription } from "./AnchoredRadialSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var RadialAreaSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeriesDescription, _super);
    function RadialAreaSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.el = null;
        return _this;
    }
    RadialAreaSeriesDescription.prototype.get_type = function () {
        return "RadialAreaSeries";
    };
    Object.defineProperty(RadialAreaSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.el;
        },
        set: function (a) {
            this.el = a;
            this.e("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    RadialAreaSeriesDescription.$t = markType(RadialAreaSeriesDescription, 'RadialAreaSeriesDescription', AnchoredRadialSeriesDescription.$);
    return RadialAreaSeriesDescription;
}(AnchoredRadialSeriesDescription));
export { RadialAreaSeriesDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/RadialAreaSeriesDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnchoredRadialSeriesDescription } from "./AnchoredRadialSeriesDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var RadialAreaSeriesDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(RadialAreaSeriesDescription, _super);
    function RadialAreaSeriesDescription() {
        var _this = _super.call(this) || this;
        _this.hv = null;
        return _this;
    }
    RadialAreaSeriesDescription.prototype.get_type = function () {
        return "RadialAreaSeries";
    };
    Object.defineProperty(RadialAreaSeriesDescription.prototype, "unknownValuePlotting", {
        get: function () {
            return this.hv;
        },
        set: function (a) {
            this.hv = a;
            this.g("UnknownValuePlotting");
        },
        enumerable: false,
        configurable: true
    });
    RadialAreaSeriesDescription.$t = markType(RadialAreaSeriesDescription, 'RadialAreaSeriesDescription', AnchoredRadialSeriesDescription.$);
    return RadialAreaSeriesDescription;
}(AnchoredRadialSeriesDescription));
export { RadialAreaSeriesDescription };
